==> humhub-1.17.4.zip: humhub-1.17.4/protected/humhub/modules/admin/messages/lv/settings.php <==
<?php

return [
    '1 month' => '1 mēnesis',
    '1 week' => '1 nedēļa',
    '1 year' => '1 gads',
    '2 weeks' => '2 nedēļas',
    '3 months' => '3 mēneši',
    '6 months' => '6 mēneši',
    'APC(u)' => 'APC(u)',
    'Advanced Settings' => 'Paplašinātie iestatījumi',
    'Allow Self-Signed Certificates?' => 'Atļaut paša parakstītus sertifikātus?',
    'Allowed file extensions' => 'Atļautie failu paplašinājumi',
    'Appearance Settings' => 'Atspoguļošanas iestatījumi',
    'Back to overview' => 'Atpakaļ uz pārskatu',
    'Base URL' => 'Pamata URL',
    'Cache Backend' => 'Kešot administrācijas paneli',
    'Dashboard' => 'Pārskats',
    'Date input format' => 'Datuma ievades formāts',
    'Default Expire Time (in seconds)' => 'Noklusētais izbeigšanās laiks (sekundēs)',
    'Default language' => 'Noklusētā valoda',
    'Default pagination size (Entries per page)' => 'Noklusētais lapošanas izmērs (Ieraksti lapā)',
    'Default stream content order' => 'Noklusētā satura straumes secība',
    'Delete' => 'Dzēst',
    'E-Mail sender address' => 'E-pasta sūtītāja adrese',
    'E-Mail sender name' => 'E-pasta sūtītāja vārds',
    'Enable user friendship system' => 'Aktivizēt lietotāju draudzības sistēmu',
    'Enabled' => 'Aktivizēts',
    'Endpoint Url' => 'Galapunkta URL',
    'File' => 'Fails',
    'General' => 'Galvenais',
    'General Settings' => 'Galvenie uzstātījumi',
    'HTML tracking code' => 'HTML izsekošanas kods',
    'Here you can configurate the registration behaviour and additinal user settings of your social network.' => 'Šeit tu vari konfigurēt reģistrēšanās procesu un papildus lietotāja uzstādījumus tavam sociālajam tīklam.',
    'Here you can configure basic settings of your social network.' => 'Šeit tu vari konfigurēt pamata uzstādījumus tavam sociālajam tīklam.',
    'Horizontal scrolling images on a mobile device' => 'Attēlu ritināšana horizontāli uz mobilajām ierīcēm',
    'Logo upload' => 'Logo augšupielāde',
    'Mail Transport Type' => 'Pasta transporta tips',
    'Maximum allowed age for logs.' => 'Maksimālais atļautais vecums žurnāla ierakstiem.',
    'Maximum upload file size (in MB)' => 'Maksimālais augšupielādes izmērs failam (MB)',
    'Name of the application' => 'Aplikācijas nosaukums',
    'No Proxy Hosts' => 'Nav Proxy hosti',
    'No caching' => 'Bez kešošanas',
    'Notification Settings' => 'Notifikāciju iestatījumi',
    'PHP APC(u) Extension missing - Type not available!' => 'Trūkst PHP APC(u) paplašinājums - tips nav pieejams!',
    'Password' => 'Parole',
    'Port' => 'Ports',
    'Port number' => 'Porta numurs',
    'Save' => 'Saglabāt',
    'Saved' => 'Saglabāts',
    'Saved and flushed cache' => 'Saglabāts un notīrīta kešatmiņa',
    'Server' => 'Serveris',
    'Show introduction tour for new users' => 'Rādīt iepazīšanās tūri jauniem lietotājiem',
    'Show user profile post form on dashboard' => 'Rādīt lietotāja profila ierakstu kontrolpanelī',
    'Sort by creation date' => 'Kārtot pēc izveidošanas datuma',
    'Sort by update date' => 'Kārtot pēc atjaunināšanas datuma',
    'Theme' => 'Tēma',
    'These settings refer to advanced topics of your social network.' => 'Šie iestatījumi attiecās uz tava sociālā tīkla palašinātajām tēmatiem.',
    'These settings refer to the appearance of your social network.' => 'Šie iestatījumi attiecās uz tava sociālā tīkla izskatu.',
    'Use X-Sendfile for File Downloads' => 'Lietot X-Sendfile failu lejupielādēm',
    'User' => 'Lietotājs',
    'User Settings' => 'Lietotāja uzstādījumi',
    'Username' => 'Lietotāja vārds',
    'never' => 'nekad',
    '"My Spaces" Sorting' => '',
    '<strong>Confirm</strong> icon deletion' => '',
    '<strong>Confirm</strong> image deletion' => '',
    '<strong>Confirm</strong> topic deletion' => '',
    'Access Token' => '',
    'Access token is not provided yet.' => '',
    'Add OEmbed provider' => '',
    'Add Topic' => '',
    'Add custom info text for maintenance mode. Displayed on the login page.' => '',
    'Add individual info text...' => '',
    'Add new provider' => '',
    'Auto format based on user language - Example: {example}' => '',
    'Comma separated list. Leave empty to allow all.' => '',
    'Configuration (Use settings from configuration file)' => '',
    'Convert to global topic' => '',
    'Could not send test email.' => '',
    'Currently no provider active!' => '',
    'Currently there are {count} records in the database dating from {dating}.' => '',
    'Custom DSN' => '',
    'Custom sort order (alphabetical if not defined)' => '',
    'Custom sort order can be defined in the Space advanced settings.' => '',
    'DSN' => '',
    'DSN Examples:' => '',
    'Default Timezone' => '',
    'Do you really want to delete this topic?' => '',
    'E-Mail' => '',
    'E-Mail reply-to' => '',
    'E.g. http://example.com/humhub' => '',
    'Edit OEmbed provider' => '',
    'Embedded content requires the user\'s consent to be loaded' => '',
    'Enable maintenance mode' => '',
    'Enabled OEmbed providers' => '',
    'Exclude media files from stream attachment list' => '',
    'Firstname Lastname (e.g. John Doe)' => '',
    'Fixed format (dd/mm/yyyy) - Example: {example}' => '',
    'Friendship' => '',
    'Global topics can be used by all users in all Spaces. They make it easier for you to define consistent keywords throughout your entire network. If users have already created topics in Spaces, you can also convert them to global topics here.' => '',
    'Icon upload' => '',
    'Inserted script tags must contain a nonce. e.g. {code}' => '',
    'Last visit' => '',
    'Maintenance mode' => '',
    'Maintenance mode restricts access to the platform and immediately logs out all users except Admins.' => '',
    'Mobile appearance' => '',
    'No Delivery (Debug Mode, Save as file)' => '',
    'Old logs can significantly increase the size of your database while providing little information.' => '',
    'Optional. Default reply address for system emails like notifications.' => '',
    'PHP (Use settings of php.ini file)' => '',
    'PHP reported a maximum of {maxUploadSize} MB' => '',
    'Prevent client caching of following scripts' => '',
    'Provider Name' => '',
    'Redis' => '',
    'Regular expression by which the link match will be checked.' => '',
    'Save & Flush Caches' => '',
    'Save & Test' => '',
    'Saved and sent test email to: {address}' => '',
    'Test message' => '',
    'Topic has been deleted!' => '',
    'Topics' => '',
    'Url Pattern' => '',
    'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => '',
    'Use SMTPS' => '',
    'User Display Name' => '',
    'User Display Name Subtitle' => '',
    'Username (e.g. john)' => '',
    'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => '',
    'You can find more configuration options here:' => '',
    'You\'re using no icon at the moment. Upload your logo now.' => '',
    'You\'re using no logo at the moment. Upload your logo now.' => '',
    'e.g. 25 (for SMTP) or 465 (for SMTPS)' => '',
    'e.g. localhost' => '',
    'e.g. smtps://user:pass@smtp.example.com:port' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/admin/messages/lv/settings.php <==
<?php

return [
    '1 month' => '1 mēnesis',
    '1 week' => '1 nedēļa',
    '1 year' => '1 gads',
    '2 weeks' => '2 nedēļas',
    '3 months' => '3 mēneši',
    '6 months' => '6 mēneši',
    'Advanced Settings' => 'Paplašinātie iestatījumi',
    'Allow Self-Signed Certificates?' => 'Atļaut paša parakstītus sertifikātus?',
    'Allowed file extensions' => 'Atļautie failu paplašinājumi',
    'Appearance Settings' => 'Atspoguļošanas iestatījumi',
    'Back to overview' => 'Atpakaļ uz pārskatu',
    'Base URL' => 'Pamata URL',
    'Dashboard' => 'Pārskats',
    'Date input format' => 'Datuma ievades formāts',
    'Default' => 'Noklusēts',
    'Default language' => 'Noklusētā valoda',
    'Default pagination size (Entries per page)' => 'Noklusētais lapošanas izmērs (Ieraksti lapā)',
    'Default stream content order' => 'Noklusētā satura straumes secība',
    'Delete' => 'Dzēst',
    'E-Mail sender address' => 'E-pasta sūtītāja adrese',
    'E-Mail sender name' => 'E-pasta sūtītāja vārds',
    'Enable user friendship system' => 'Aktivizēt lietotāju draudzības sistēmu',
    'Enabled' => 'Aktivizēts',
    'Endpoint Url' => 'Galapunkta URL',
    'General' => 'Galvenais',
    'General Settings' => 'Galvenie uzstātījumi',
    'HTML tracking code' => 'HTML izsekošanas kods',
    'Here you can configurate the registration behaviour and additinal user settings of your social network.' => 'Šeit tu vari konfigurēt reģistrēšanās procesu un papildus lietotāja uzstādījumus tavam sociālajam tīklam.',
    'Here you can configure basic settings of your social network.' => 'Šeit tu vari konfigurēt pamata uzstādījumus tavam sociālajam tīklam.',
    'Logo upload' => 'Logo augšupielāde',
    'Mail Transport Type' => 'Pasta transporta tips',
    'Maximum allowed age for logs.' => 'Maksimālais atļautais vecums žurnāla ierakstiem.',
    'Maximum upload file size (in MB)' => 'Maksimālais augšupielādes izmērs failam (MB)',
    'Name of the application' => 'Aplikācijas nosaukums',
    'No Proxy Hosts' => 'Nav Proxy hosti',
    'Notification Settings' => 'Notifikāciju iestatījumi',
    'Password' => 'Parole',
    'Port' => 'Ports',
    'Port number' => 'Porta numurs',
    'Save' => 'Saglabāt',
    'Server' => 'Serveris',
    'Show introduction tour for new users' => 'Rādīt iepazīšanās tūri jauniem lietotājiem',
    'Show user profile post form on dashboard' => 'Rādīt lietotāja profila ierakstu kontrolpanelī',
    'Sort by creation date' => 'Kārtot pēc izveidošanas datuma',
    'Sort by update date' => 'Kārtot pēc atjaunināšanas datuma',
    'Theme' => 'Tēma',
    'These settings refer to advanced topics of your social network.' => 'Šie iestatījumi attiecās uz tava sociālā tīkla palašinātajām tēmatiem.',
    'These settings refer to the appearance of your social network.' => 'Šie iestatījumi attiecās uz tava sociālā tīkla izskatu.',
    'Use X-Sendfile for File Downloads' => 'Lietot X-Sendfile failu lejupielādēm',
    'User' => 'Lietotājs',
    'User Settings' => 'Lietotāja uzstādījumi',
    'Username' => 'Lietotāja vārds',
    'never' => 'nekad',
    '"My Spaces" Sorting' => '',
    '<strong>Confirm</strong> icon deletion' => '',
    '<strong>Confirm</strong> image deletion' => '',
    '<strong>Confirm</strong> topic deletion' => '',
    '<strong>Mobile App</strong> Debug Page' => '',
    'A dedicated image can be uploaded in the Appearance admin page.' => '',
    'Accent color' => '',
    'Access Token' => '',
    'Access token is not provided yet.' => '',
    'Add OEmbed provider' => '',
    'Add Topic' => '',
    'Add custom info text for maintenance mode. Displayed on the login page.' => '',
    'Add individual info text...' => '',
    'Add new provider' => '',
    'Allow establishing verified connections with the mobile app to enable Android app links and iOS universal links and redirect web content to the mobile app.' => '',
    'Auto format based on user language - Example: {example}' => '',
    'Caches flushed successfully' => '',
    'Cannot compile SCSS to CSS:' => '',
    'Comma separated list. Leave empty to allow all.' => '',
    'Configuration (Use settings from configuration file)' => '',
    'Convert to global topic' => '',
    'Could not send test email.' => '',
    'Currently no provider active!' => '',
    'Currently there are {count} records in the database dating from {dating}.' => '',
    'Custom DSN' => '',
    'Custom SCSS' => '',
    'Custom sort order (alphabetical if not defined)' => '',
    'Custom sort order can be defined in the Space advanced settings.' => '',
    'DSN' => '',
    'DSN Examples:' => '',
    'Danger color' => '',
    'Dark color' => '',
    'Debug' => '',
    'Default Timezone' => '',
    'Do you really want to delete this topic?' => '',
    'Domain URLs to whitelist, separated by comma' => '',
    'E-Mail' => '',
    'E-Mail reply-to' => '',
    'E.g. URLs of the SSO service providers' => '',
    'E.g. http://example.com/humhub' => '',
    'Edit OEmbed provider' => '',
    'Email Header Image' => '',
    'Embedded content requires the user\'s consent to be loaded' => '',
    'Enable Link Redirection Service' => '',
    'Enable maintenance mode' => '',
    'Enabled OEmbed providers' => '',
    'Exclude media files from stream attachment list' => '',
    'Firstname Lastname (e.g. John Doe)' => '',
    'Fixed format (dd/mm/yyyy) - Example: {example}' => '',
    'Flush Caches' => '',
    'Friendship' => '',
    'Global topics can be used by all users in all Spaces. They make it easier for you to define consistent keywords throughout your entire network. If users have already created topics in Spaces, you can also convert them to global topics here.' => '',
    'Icon upload' => '',
    'In order for links to open in the app on mobile devices, rather than in the mobile browser, all links (e.g. notification emails) need to be routed through the HumHub proxy server.' => '',
    'Info color' => '',
    'Inserted script tags must contain a nonce. e.g. {code}' => '',
    'Invalid URL format: {domain}' => '',
    'Last visit' => '',
    'Light color' => '',
    'Login Background' => '',
    'Maintenance mode' => '',
    'Maintenance mode restricts access to the platform and immediately logs out all users except Admins.' => '',
    'Mobile App' => '',
    'No Delivery (Debug Mode, Save as file)' => '',
    'Old logs can significantly increase the size of your database while providing little information.' => '',
    'Optional. Default reply address for system emails like notifications.' => '',
    'PHP (Use settings of php.ini file)' => '',
    'PHP reported a maximum of {maxUploadSize} MB' => '',
    'Please enable <a href="{url}" target="_blank">Pretty URLs</a> for proper working of the well-known files.' => '',
    'Primary color' => '',
    'Provider Name' => '',
    'Recommended minimum height: {recommendedMinHeight}px (minimum {minWidth} x {minHeight} px).' => '',
    'Recommended size: {recommendedWidth} × {recommendedHeight}px (minimum {minWidth} x {minHeight} px).' => '',
    'Regular expression by which the link match will be checked.' => '',
    'Save & Test' => '',
    'Saved and sent test email to: {address}' => '',
    'Secondary color' => '',
    'Show network name instead of logo in email header' => '',
    'Success color' => '',
    'Test message' => '',
    'Theme customization' => '',
    'Topic has been deleted!' => '',
    'Topics' => '',
    'URL to the file {fileNameLink}' => '',
    'Url Pattern' => '',
    'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => '',
    'Use SMTPS' => '',
    'Use Sassy CSS syntax (SCSS)' => '',
    'User Display Name' => '',
    'User Display Name Subtitle' => '',
    'Username (e.g. john)' => '',
    'Warning color' => '',
    'Well-known file {fileName}' => '',
    'Well-known files' => '',
    'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => '',
    'You can find more configuration options here:' => '',
    'You\'re using no icon at the moment. Upload your logo now.' => '',
    'You\'re using no logo at the moment. Upload your logo now.' => '',
    'e.g. 25 (for SMTP) or 465 (for SMTPS)' => '',
    'e.g. localhost' => '',
    'e.g. smtps://user:pass@smtp.example.com:port' => '',
];
